@@ -14,7 +14,7 @@ Several spline interpolation/approximation methods for the gridding of scattered
 
 from PySAGA.helper import Tool_Wrapper
 
-def Thin_Plate_Spline(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REGULARISATION=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
+def Thin_Plate_Spline(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REGULARISATION=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
     '''
     Thin Plate Spline
     ----------
@@ -34,6 +34,7 @@ def Thin_Plate_Spline(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, F
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - REGULARISATION [`floating point number`] : Regularisation. Minimum: 0.000000 Default: 0.000100
@@ -62,6 +63,7 @@ def Thin_Plate_Spline(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, F
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('REGULARISATION', REGULARISATION)
@@ -73,7 +75,7 @@ def Thin_Plate_Spline(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, F
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_spline_1(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REGULARISATION=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
+def run_tool_grid_spline_1(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REGULARISATION=None, SEARCH_RANGE=None, SEARCH_RADIUS=None, SEARCH_POINTS_ALL=None, SEARCH_POINTS_MIN=None, SEARCH_POINTS_MAX=None, Verbose=2):
     '''
     Thin Plate Spline
     ----------
@@ -93,6 +95,7 @@ def run_tool_grid_spline_1(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=No
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - REGULARISATION [`floating point number`] : Regularisation. Minimum: 0.000000 Default: 0.000100
@@ -121,6 +124,7 @@ def run_tool_grid_spline_1(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=No
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('REGULARISATION', REGULARISATION)
@@ -132,7 +136,7 @@ def run_tool_grid_spline_1(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=No
         return Tool.Execute(Verbose)
     return False
 
-def Thin_Plate_Spline_TIN(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REGULARISATION=None, LEVEL=None, FRAME=None, Verbose=2):
+def Thin_Plate_Spline_TIN(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REGULARISATION=None, LEVEL=None, FRAME=None, Verbose=2):
     '''
     Thin Plate Spline (TIN)
     ----------
@@ -152,6 +156,7 @@ def Thin_Plate_Spline_TIN(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=Non
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - REGULARISATION [`floating point number`] : Regularisation. Minimum: 0.000000 Default: 0.000100
@@ -177,6 +182,7 @@ def Thin_Plate_Spline_TIN(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=Non
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('REGULARISATION', REGULARISATION)
@@ -185,7 +191,7 @@ def Thin_Plate_Spline_TIN(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=Non
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_spline_2(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REGULARISATION=None, LEVEL=None, FRAME=None, Verbose=2):
+def run_tool_grid_spline_2(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, REGULARISATION=None, LEVEL=None, FRAME=None, Verbose=2):
     '''
     Thin Plate Spline (TIN)
     ----------
@@ -205,6 +211,7 @@ def run_tool_grid_spline_2(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=No
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - REGULARISATION [`floating point number`] : Regularisation. Minimum: 0.000000 Default: 0.000100
@@ -230,6 +237,7 @@ def run_tool_grid_spline_2(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=No
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('REGULARISATION', REGULARISATION)
@@ -238,7 +246,7 @@ def run_tool_grid_spline_2(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=No
         return Tool.Execute(Verbose)
     return False
 
-def BSpline_Approximation(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, LEVEL=None, Verbose=2):
+def BSpline_Approximation(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, LEVEL=None, Verbose=2):
     '''
     B-Spline Approximation
     ----------
@@ -258,6 +266,7 @@ def BSpline_Approximation(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=Non
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - LEVEL [`floating point number`] : Range. Minimum: 0.001000 Default: 1.000000 B-spline range expressed as number of cells.
@@ -281,13 +290,14 @@ def BSpline_Approximation(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=Non
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('LEVEL', LEVEL)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_spline_3(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, LEVEL=None, Verbose=2):
+def run_tool_grid_spline_3(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, LEVEL=None, Verbose=2):
     '''
     B-Spline Approximation
     ----------
@@ -307,6 +317,7 @@ def run_tool_grid_spline_3(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=No
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - LEVEL [`floating point number`] : Range. Minimum: 0.001000 Default: 1.000000 B-spline range expressed as number of cells.
@@ -330,13 +341,14 @@ def run_tool_grid_spline_3(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=No
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('LEVEL', LEVEL)
         return Tool.Execute(Verbose)
     return False
 
-def Multilevel_BSpline(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, METHOD=None, EPSILON=None, LEVEL_MAX=None, Verbose=2):
+def Multilevel_BSpline(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, METHOD=None, EPSILON=None, LEVEL_MAX=None, Verbose=2):
     '''
     Multilevel B-Spline
     ----------
@@ -358,6 +370,7 @@ def Multilevel_BSpline(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None,
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - METHOD [`choice`] : Refinement. Available Choices: [0] no [1] yes Default: 0
@@ -383,6 +396,7 @@ def Multilevel_BSpline(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None,
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('METHOD', METHOD)
@@ -391,7 +405,7 @@ def Multilevel_BSpline(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_spline_4(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, METHOD=None, EPSILON=None, LEVEL_MAX=None, Verbose=2):
+def run_tool_grid_spline_4(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, METHOD=None, EPSILON=None, LEVEL_MAX=None, Verbose=2):
     '''
     Multilevel B-Spline
     ----------
@@ -413,6 +427,7 @@ def run_tool_grid_spline_4(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=No
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - METHOD [`choice`] : Refinement. Available Choices: [0] no [1] yes Default: 0
@@ -438,6 +453,7 @@ def run_tool_grid_spline_4(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=No
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('METHOD', METHOD)
@@ -446,7 +462,7 @@ def run_tool_grid_spline_4(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=No
         return Tool.Execute(Verbose)
     return False
 
-def Multilevel_BSpline_from_Grid_Points(GRID=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, GRID_GRIDSYSTEM=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, DATATYPE=None, METHOD=None, EPSILON=None, LEVEL_MAX=None, Verbose=2):
+def Multilevel_BSpline_from_Grid_Points(GRID=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, GRID_GRIDSYSTEM=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, DATATYPE=None, METHOD=None, EPSILON=None, LEVEL_MAX=None, Verbose=2):
     '''
     Multilevel B-Spline from Grid Points
     ----------
@@ -467,6 +483,7 @@ def Multilevel_BSpline_from_Grid_Points(GRID=None, TARGET_TEMPLATE=None, TARGET_
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - DATATYPE [`choice`] : Data Type. Available Choices: [0] same as input grid [1] 4 byte floating point number Default: 0
@@ -493,6 +510,7 @@ def Multilevel_BSpline_from_Grid_Points(GRID=None, TARGET_TEMPLATE=None, TARGET_
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('DATATYPE', DATATYPE)
@@ -502,7 +520,7 @@ def Multilevel_BSpline_from_Grid_Points(GRID=None, TARGET_TEMPLATE=None, TARGET_
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_spline_5(GRID=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, GRID_GRIDSYSTEM=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, DATATYPE=None, METHOD=None, EPSILON=None, LEVEL_MAX=None, Verbose=2):
+def run_tool_grid_spline_5(GRID=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, GRID_GRIDSYSTEM=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, DATATYPE=None, METHOD=None, EPSILON=None, LEVEL_MAX=None, Verbose=2):
     '''
     Multilevel B-Spline from Grid Points
     ----------
@@ -523,6 +541,7 @@ def run_tool_grid_spline_5(GRID=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - DATATYPE [`choice`] : Data Type. Available Choices: [0] same as input grid [1] 4 byte floating point number Default: 0
@@ -549,6 +568,7 @@ def run_tool_grid_spline_5(GRID=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('DATATYPE', DATATYPE)
@@ -558,7 +578,7 @@ def run_tool_grid_spline_5(GRID=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None
         return Tool.Execute(Verbose)
     return False
 
-def Cubic_Spline_Approximation(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, NPMIN=None, NPMAX=None, NPPC=None, K=None, Verbose=2):
+def Cubic_Spline_Approximation(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, NPMIN=None, NPMAX=None, NPPC=None, K=None, Verbose=2):
     '''
     Cubic Spline Approximation
     ----------
@@ -584,6 +604,7 @@ def Cubic_Spline_Approximation(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRI
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - NPMIN [`integer number`] : Minimal Number of Points. Minimum: 0 Default: 3
@@ -610,6 +631,7 @@ def Cubic_Spline_Approximation(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRI
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('NPMIN', NPMIN)
@@ -619,7 +641,7 @@ def Cubic_Spline_Approximation(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRI
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_spline_6(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, NPMIN=None, NPMAX=None, NPPC=None, K=None, Verbose=2):
+def run_tool_grid_spline_6(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, NPMIN=None, NPMAX=None, NPPC=None, K=None, Verbose=2):
     '''
     Cubic Spline Approximation
     ----------
@@ -645,6 +667,7 @@ def run_tool_grid_spline_6(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=No
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - NPMIN [`integer number`] : Minimal Number of Points. Minimum: 0 Default: 3
@@ -671,6 +694,7 @@ def run_tool_grid_spline_6(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=No
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('NPMIN', NPMIN)
@@ -680,7 +704,7 @@ def run_tool_grid_spline_6(SHAPES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=No
         return Tool.Execute(Verbose)
     return False
 
-def Multilevel_BSpline_for_Categories(POINTS=None, TARGET_TEMPLATE=None, CATEGORIES=None, PROPABILITY=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def Multilevel_BSpline_for_Categories(POINTS=None, TARGET_TEMPLATE=None, CATEGORIES=None, PROPABILITY=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
     '''
     Multilevel B-Spline for Categories
     ----------
@@ -701,6 +725,7 @@ def Multilevel_BSpline_for_Categories(POINTS=None, TARGET_TEMPLATE=None, CATEGOR
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
 
@@ -724,12 +749,13 @@ def Multilevel_BSpline_for_Categories(POINTS=None, TARGET_TEMPLATE=None, CATEGOR
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_spline_7(POINTS=None, TARGET_TEMPLATE=None, CATEGORIES=None, PROPABILITY=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def run_tool_grid_spline_7(POINTS=None, TARGET_TEMPLATE=None, CATEGORIES=None, PROPABILITY=None, FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
     '''
     Multilevel B-Spline for Categories
     ----------
@@ -750,6 +776,7 @@ def run_tool_grid_spline_7(POINTS=None, TARGET_TEMPLATE=None, CATEGORIES=None, P
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
 
@@ -773,12 +800,13 @@ def run_tool_grid_spline_7(POINTS=None, TARGET_TEMPLATE=None, CATEGORIES=None, P
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         return Tool.Execute(Verbose)
     return False
 
-def Multilevel_BSpline_3D(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD=None, Z_SCALE=None, V_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, EPSILON=None, LEVEL_MAX=None, Verbose=2):
+def Multilevel_BSpline_3D(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD=None, Z_SCALE=None, V_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, EPSILON=None, LEVEL_MAX=None, Verbose=2):
     '''
     Multilevel B-Spline (3D)
     ----------
@@ -802,6 +830,7 @@ def Multilevel_BSpline_3D(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TARGET_USER_ZSIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
@@ -832,6 +861,7 @@ def Multilevel_BSpline_3D(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TARGET_USER_ZSIZE', TARGET_USER_ZSIZE)
@@ -843,7 +873,7 @@ def Multilevel_BSpline_3D(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_spline_8(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD=None, Z_SCALE=None, V_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, EPSILON=None, LEVEL_MAX=None, Verbose=2):
+def run_tool_grid_spline_8(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIELD=None, Z_SCALE=None, V_FIELD=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, TARGET_USER_ZSIZE=None, TARGET_USER_ZMIN=None, TARGET_USER_ZMAX=None, TARGET_USER_ZNUM=None, EPSILON=None, LEVEL_MAX=None, Verbose=2):
     '''
     Multilevel B-Spline (3D)
     ----------
@@ -867,6 +897,7 @@ def run_tool_grid_spline_8(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIEL
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
     - TARGET_USER_ZSIZE [`floating point number`] : Cellsize. Minimum: 0.000000 Default: 1.000000
@@ -897,6 +928,7 @@ def run_tool_grid_spline_8(POINTS=None, TARGET_TEMPLATE=None, GRIDS=None, Z_FIEL
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         Tool.Set_Option('TARGET_USER_ZSIZE', TARGET_USER_ZSIZE)
