@@ -11,7 +11,7 @@ Description
 ----------
 Tools that use the Point Data Abstraction Library (PDAL).
 
-PDAL Version: 2.5.0 (git-version: Release)
+PDAL Version: 2.7.2 (git-version: Release)
 '''
 
 from PySAGA.helper import Tool_Wrapper
@@ -23,7 +23,7 @@ def Import_Point_Cloud(POINTS=None, FILES=None, VARS=None, VAR_TIME=None, VAR_IN
     [io_pdal.0]\n
     The tool allows one to import point cloud data from various file formats using the "Point Data Abstraction Library" (PDAL).\n
     By default, all supported attributes will be imported. Note that the list of attributes supported by the tool is currently based on the attributes defined in the ASPRS LAS specification.\n
-    PDAL Version:2.5.0 (git-version: Release)\n
+    PDAL Version:2.7.2 (git-version: Release)\n
     The following point cloud formats are currently supported:\n
     ============\n
     Name	Extension	Description\n
@@ -37,9 +37,8 @@ def Import_Point_Cloud(POINTS=None, FILES=None, VARS=None, VAR_TIME=None, VAR_IN
     See http://nsidc.org/data/docs/daac/icebridge/ilatm1b/index.html\n
     for more information.\n
     readers.ilvis2		ILVIS2 Reader\n
-    readers.las	las;laz	ASPRS LAS 1.0 - 1.4 read support. LASzip support is also\n
-    enabled through this driver if LASzip was found during\n
-    compilation.\n
+    readers.las	las;laz	ASPRS LAS 1.0 - 1.4 read support\n
+    readers.nitf		NITF Reader\n
     readers.obj	obj	Obj Reader\n
     readers.pcd	pcd	Read data in the Point Cloud Library (PCL) format.\n
     readers.pgpointcloud		Read data from pgpointcloud format. "query" option needs to be a\n
@@ -54,6 +53,7 @@ def Import_Point_Cloud(POINTS=None, FILES=None, VARS=None, VAR_TIME=None, VAR_IN
     readers.stac		STAC Reader\n
     readers.terrasolid	bin	TerraSolid Reader\n
     readers.text	csv;txt	Text Reader\n
+    readers.tiledb		Read data from a TileDB array.\n
     readers.tindex	tindex	TileIndex Reader\n
     ============\n
     Arguments
@@ -112,7 +112,7 @@ def run_tool_io_pdal_0(POINTS=None, FILES=None, VARS=None, VAR_TIME=None, VAR_IN
     [io_pdal.0]\n
     The tool allows one to import point cloud data from various file formats using the "Point Data Abstraction Library" (PDAL).\n
     By default, all supported attributes will be imported. Note that the list of attributes supported by the tool is currently based on the attributes defined in the ASPRS LAS specification.\n
-    PDAL Version:2.5.0 (git-version: Release)\n
+    PDAL Version:2.7.2 (git-version: Release)\n
     The following point cloud formats are currently supported:\n
     ============\n
     Name	Extension	Description\n
@@ -126,9 +126,8 @@ def run_tool_io_pdal_0(POINTS=None, FILES=None, VARS=None, VAR_TIME=None, VAR_IN
     See http://nsidc.org/data/docs/daac/icebridge/ilatm1b/index.html\n
     for more information.\n
     readers.ilvis2		ILVIS2 Reader\n
-    readers.las	las;laz	ASPRS LAS 1.0 - 1.4 read support. LASzip support is also\n
-    enabled through this driver if LASzip was found during\n
-    compilation.\n
+    readers.las	las;laz	ASPRS LAS 1.0 - 1.4 read support\n
+    readers.nitf		NITF Reader\n
     readers.obj	obj	Obj Reader\n
     readers.pcd	pcd	Read data in the Point Cloud Library (PCL) format.\n
     readers.pgpointcloud		Read data from pgpointcloud format. "query" option needs to be a\n
@@ -143,6 +142,7 @@ def run_tool_io_pdal_0(POINTS=None, FILES=None, VARS=None, VAR_TIME=None, VAR_IN
     readers.stac		STAC Reader\n
     readers.terrasolid	bin	TerraSolid Reader\n
     readers.text	csv;txt	Text Reader\n
+    readers.tiledb		Read data from a TileDB array.\n
     readers.tindex	tindex	TileIndex Reader\n
     ============\n
     Arguments
@@ -202,7 +202,7 @@ def Export_LASLAZ_File(POINTS=None, T=None, r=None, n=None, i=None, c=None, SCH=
     The tool allows one to export a point cloud as ASPRS LAS (or compressed LAZ) file using the "Point Data Abstraction Library" (PDAL).\n
     The file extension of the output file determines whether the file is written compressed (*.laz) or uncompressed (*.las).\n
     The number and type of attributes that can be exported depends on the chosen LAS file version and point data record format. Please have a look at the ASPRS LAS specification on how these formats are defined.\n
-    PDAL Version:2.5.0 (git-version: Release)\n
+    PDAL Version:2.7.2 (git-version: Release)\n
     Arguments
     ----------
     - POINTS [`input point cloud`] : Point Cloud. The point cloud to export.
@@ -278,7 +278,7 @@ def run_tool_io_pdal_1(POINTS=None, T=None, r=None, n=None, i=None, c=None, SCH=
     The tool allows one to export a point cloud as ASPRS LAS (or compressed LAZ) file using the "Point Data Abstraction Library" (PDAL).\n
     The file extension of the output file determines whether the file is written compressed (*.laz) or uncompressed (*.las).\n
     The number and type of attributes that can be exported depends on the chosen LAS file version and point data record format. Please have a look at the ASPRS LAS specification on how these formats are defined.\n
-    PDAL Version:2.5.0 (git-version: Release)\n
+    PDAL Version:2.7.2 (git-version: Release)\n
     Arguments
     ----------
     - POINTS [`input point cloud`] : Point Cloud. The point cloud to export.
