@@ -319,40 +319,41 @@ def Point_Cloud_Reclassifier__Subset_Extractor(INPUT=None, RETAB_2=None, RESULT=
     Point Cloud Reclassifier / Subset Extractor
     ----------
     [pointcloud_tools.6]\n
-    The tool can be used to either reclassify a Point Cloud attribute or to extract a subset of a Point Cloud based on the values of an attribute.\n
-    The tool provides three different options:\n
-    (a) reclassification of (or extraction based on) single values,\n
-    (b) reclassification of (or extraction based on) a range of values and\n
-    (c) reclassification of (or extraction based on) value ranges specified in a lookup table.\n
+    The tool can be used to either reclassify a Point Cloud attribute, to extract, or drop a subset of a Point Cloud based on the values of an attribute.\n
+    The tool provides three different methods for selection of points to become reclassified/extracted/deleted:\n
+    (-) single value\n
+    (-) value range\n
+    (-) value ranges specified in a lookup table\n
     Each of these three options provides it's own parameters. The 'new value' parameters are irrelevant in case a subset is extracted.\n
     In addition to these settings, two special cases ('NoData values' and 'other values' not included in the parameter setup) are supported:\n
     In mode (a) and (b) the 'NoData option' is evaluated before the method settings, in mode (c) the option is evaluated only if the NoData value isn't included in the lookup table.\n
     The 'other values' option is always evaluated after checking the method settings.\n
+    Have in mind that subset deletion will be performed on the input point cloud!\n
     Arguments
     ----------
     - INPUT [`input point cloud`] : Point Cloud. Point Cloud to reclassify/extract
     - RETAB_2 [`optional input table`] : Lookup Table. Lookup table used in method "user supplied table"
     - RESULT [`output point cloud`] : Result. Reclassified or extracted Point Cloud.
     - ATTRIB [`table field`] : Attribute. Attribute to process.
-    - MODE [`choice`] : Mode of operation. Available Choices: [0] Reclassify [1] Extract Subset Default: 0 Choose whether to reclassify a Point Cloud or to extract a subset from a Point Cloud.
+    - MODE [`choice`] : Mode of Operation. Available Choices: [0] Reclassify [1] Extract Subset [2] Drop Subset Default: 0 Choose whether to reclassify a Point Cloud or to extract a subset from a Point Cloud.
     - CREATE_ATTRIB [`boolean`] : Create new Attribute. Default: 0 Check this to create a new attribute with the reclassification result. If unchecked, the existing attribute is updated.
-    - METHOD [`choice`] : Method. Available Choices: [0] single [1] range [2] simple table [3] user supplied table Default: 0 Select the desired method: 1. a single value or a range defined by a single value is reclassified, 2. a range of values is reclassified, 3. the lookup table is used to reclassify the grid.
-    - OLD [`floating point number`] : old value. Default: 0.000000 Value to reclassify.
-    - NEW [`floating point number`] : new value. Default: 1.000000 New value.
-    - SOPERATOR [`choice`] : operator. Available Choices: [0] = [1] < [2] <= [3] >= [4] > Default: 0 Select the desired operator (<;.;=; >;.); it is possible to define a range above or below the old value.
-    - MIN [`floating point number`] : minimum value. Default: 0.000000 Minimum value of the range to be reclassified.
-    - MAX [`floating point number`] : maximum value. Default: 10.000000 Maximum value of the range to be reclassified.
-    - RNEW [`floating point number`] : new value. Default: 5.000000 new value
-    - ROPERATOR [`choice`] : operator. Available Choices: [0] <= [1] < Default: 0 Select operator: eg. min < value < max.
+    - METHOD [`choice`] : Selection Method. Available Choices: [0] single value [1] value range [2] simple table [3] user supplied table Default: 0 Select the desired method: 1. a single value or a range defined by a single value is reclassified, 2. a range of values is reclassified, 3. the lookup table is used to reclassify the grid.
+    - OLD [`floating point number`] : Value. Default: 0.000000 Value to reclassify, extract or drop.
+    - NEW [`floating point number`] : New Value. Default: 1.000000 New value.
+    - SOPERATOR [`choice`] : Operator. Available Choices: [0] = [1] < [2] <= [3] >= [4] > [5] <> Default: 0 Select the desired operator (<;.;=; >;.); it is possible to define a range above or below the old value.
+    - MIN [`floating point number`] : Minimum Value. Default: 0.000000 Minimum value of the range to be reclassified.
+    - MAX [`floating point number`] : Maximum Value. Default: 10.000000 Maximum value of the range to be reclassified.
+    - RNEW [`floating point number`] : New Value. Default: 5.000000 new value
+    - ROPERATOR [`choice`] : Operator. Available Choices: [0] minimum <= value <= maximum [1] minimum < value < maximum [2] value < minimum or value > maximum [3] value <= minimum or value >= maximum Default: 0 Select operator: eg. min < value < max.
     - RETAB [`static table`] : Lookup Table. 3 Fields: - 1. [8 byte floating point number] minimum - 2. [8 byte floating point number] maximum - 3. [8 byte floating point number] new  Lookup table used in method "table"
-    - TOPERATOR [`choice`] : operator. Available Choices: [0] min <= value < max [1] min <= value <= max [2] min < value <= max [3] min < value < max Default: 0 Select the desired operator (min < value < max; min . value < max; min .value . max; min < value . max).
-    - F_MIN [`table field`] : minimum value
-    - F_MAX [`table field`] : maximum value
-    - F_CODE [`table field`] : new value
-    - NODATAOPT [`boolean`] : no data values. Default: 0 Use this option to reclassify No-Data values independently of the method settings.
-    - NODATA [`floating point number`] : new value. Default: 0.000000 new value
-    - OTHEROPT [`boolean`] : other values. Default: 0 Use this option to reclassify all other values that are not specified in the options above.
-    - OTHERS [`floating point number`] : new value. Default: 0.000000 new value
+    - TOPERATOR [`choice`] : Operator. Available Choices: [0] minimum <= value < maximum [1] minimum <= value <= maximum [2] minimum < value <= maximum [3] minimum < value < maximum Default: 0 Select the desired operator (min < value < max; min . value < max; min .value . max; min < value . max).
+    - F_MIN [`table field`] : Minimum Value
+    - F_MAX [`table field`] : Maximum Value
+    - F_CODE [`table field`] : New Value
+    - NODATAOPT [`boolean`] : No-Data Values. Default: 0 Use this option to reclassify No-Data values independently of the method settings.
+    - NODATA [`floating point number`] : New Value. Default: 0.000000 new value
+    - OTHEROPT [`boolean`] : Other Values. Default: 0 Use this option to reclassify all other values that are not specified in the options above.
+    - OTHERS [`floating point number`] : New Value. Default: 0.000000 new value
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -392,40 +393,41 @@ def run_tool_pointcloud_tools_6(INPUT=None, RETAB_2=None, RESULT=None, ATTRIB=No
     Point Cloud Reclassifier / Subset Extractor
     ----------
     [pointcloud_tools.6]\n
-    The tool can be used to either reclassify a Point Cloud attribute or to extract a subset of a Point Cloud based on the values of an attribute.\n
-    The tool provides three different options:\n
-    (a) reclassification of (or extraction based on) single values,\n
-    (b) reclassification of (or extraction based on) a range of values and\n
-    (c) reclassification of (or extraction based on) value ranges specified in a lookup table.\n
+    The tool can be used to either reclassify a Point Cloud attribute, to extract, or drop a subset of a Point Cloud based on the values of an attribute.\n
+    The tool provides three different methods for selection of points to become reclassified/extracted/deleted:\n
+    (-) single value\n
+    (-) value range\n
+    (-) value ranges specified in a lookup table\n
     Each of these three options provides it's own parameters. The 'new value' parameters are irrelevant in case a subset is extracted.\n
     In addition to these settings, two special cases ('NoData values' and 'other values' not included in the parameter setup) are supported:\n
     In mode (a) and (b) the 'NoData option' is evaluated before the method settings, in mode (c) the option is evaluated only if the NoData value isn't included in the lookup table.\n
     The 'other values' option is always evaluated after checking the method settings.\n
+    Have in mind that subset deletion will be performed on the input point cloud!\n
     Arguments
     ----------
     - INPUT [`input point cloud`] : Point Cloud. Point Cloud to reclassify/extract
     - RETAB_2 [`optional input table`] : Lookup Table. Lookup table used in method "user supplied table"
     - RESULT [`output point cloud`] : Result. Reclassified or extracted Point Cloud.
     - ATTRIB [`table field`] : Attribute. Attribute to process.
-    - MODE [`choice`] : Mode of operation. Available Choices: [0] Reclassify [1] Extract Subset Default: 0 Choose whether to reclassify a Point Cloud or to extract a subset from a Point Cloud.
+    - MODE [`choice`] : Mode of Operation. Available Choices: [0] Reclassify [1] Extract Subset [2] Drop Subset Default: 0 Choose whether to reclassify a Point Cloud or to extract a subset from a Point Cloud.
     - CREATE_ATTRIB [`boolean`] : Create new Attribute. Default: 0 Check this to create a new attribute with the reclassification result. If unchecked, the existing attribute is updated.
-    - METHOD [`choice`] : Method. Available Choices: [0] single [1] range [2] simple table [3] user supplied table Default: 0 Select the desired method: 1. a single value or a range defined by a single value is reclassified, 2. a range of values is reclassified, 3. the lookup table is used to reclassify the grid.
-    - OLD [`floating point number`] : old value. Default: 0.000000 Value to reclassify.
-    - NEW [`floating point number`] : new value. Default: 1.000000 New value.
-    - SOPERATOR [`choice`] : operator. Available Choices: [0] = [1] < [2] <= [3] >= [4] > Default: 0 Select the desired operator (<;.;=; >;.); it is possible to define a range above or below the old value.
-    - MIN [`floating point number`] : minimum value. Default: 0.000000 Minimum value of the range to be reclassified.
-    - MAX [`floating point number`] : maximum value. Default: 10.000000 Maximum value of the range to be reclassified.
-    - RNEW [`floating point number`] : new value. Default: 5.000000 new value
-    - ROPERATOR [`choice`] : operator. Available Choices: [0] <= [1] < Default: 0 Select operator: eg. min < value < max.
+    - METHOD [`choice`] : Selection Method. Available Choices: [0] single value [1] value range [2] simple table [3] user supplied table Default: 0 Select the desired method: 1. a single value or a range defined by a single value is reclassified, 2. a range of values is reclassified, 3. the lookup table is used to reclassify the grid.
+    - OLD [`floating point number`] : Value. Default: 0.000000 Value to reclassify, extract or drop.
+    - NEW [`floating point number`] : New Value. Default: 1.000000 New value.
+    - SOPERATOR [`choice`] : Operator. Available Choices: [0] = [1] < [2] <= [3] >= [4] > [5] <> Default: 0 Select the desired operator (<;.;=; >;.); it is possible to define a range above or below the old value.
+    - MIN [`floating point number`] : Minimum Value. Default: 0.000000 Minimum value of the range to be reclassified.
+    - MAX [`floating point number`] : Maximum Value. Default: 10.000000 Maximum value of the range to be reclassified.
+    - RNEW [`floating point number`] : New Value. Default: 5.000000 new value
+    - ROPERATOR [`choice`] : Operator. Available Choices: [0] minimum <= value <= maximum [1] minimum < value < maximum [2] value < minimum or value > maximum [3] value <= minimum or value >= maximum Default: 0 Select operator: eg. min < value < max.
     - RETAB [`static table`] : Lookup Table. 3 Fields: - 1. [8 byte floating point number] minimum - 2. [8 byte floating point number] maximum - 3. [8 byte floating point number] new  Lookup table used in method "table"
-    - TOPERATOR [`choice`] : operator. Available Choices: [0] min <= value < max [1] min <= value <= max [2] min < value <= max [3] min < value < max Default: 0 Select the desired operator (min < value < max; min . value < max; min .value . max; min < value . max).
-    - F_MIN [`table field`] : minimum value
-    - F_MAX [`table field`] : maximum value
-    - F_CODE [`table field`] : new value
-    - NODATAOPT [`boolean`] : no data values. Default: 0 Use this option to reclassify No-Data values independently of the method settings.
-    - NODATA [`floating point number`] : new value. Default: 0.000000 new value
-    - OTHEROPT [`boolean`] : other values. Default: 0 Use this option to reclassify all other values that are not specified in the options above.
-    - OTHERS [`floating point number`] : new value. Default: 0.000000 new value
+    - TOPERATOR [`choice`] : Operator. Available Choices: [0] minimum <= value < maximum [1] minimum <= value <= maximum [2] minimum < value <= maximum [3] minimum < value < maximum Default: 0 Select the desired operator (min < value < max; min . value < max; min .value . max; min < value . max).
+    - F_MIN [`table field`] : Minimum Value
+    - F_MAX [`table field`] : Maximum Value
+    - F_CODE [`table field`] : New Value
+    - NODATAOPT [`boolean`] : No-Data Values. Default: 0 Use this option to reclassify No-Data values independently of the method settings.
+    - NODATA [`floating point number`] : New Value. Default: 0.000000 new value
+    - OTHEROPT [`boolean`] : Other Values. Default: 0 Use this option to reclassify all other values that are not specified in the options above.
+    - OTHERS [`floating point number`] : New Value. Default: 0.000000 new value
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
