@@ -60,12 +60,17 @@ def run_tool_shapes_lines_0(POLYGONS=None, LINES=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Convert_Points_to_Lines(POINTS=None, LINES=None, ORDER=None, SEPARATE=None, ELEVATION=None, MAXDIST=None, Verbose=2):
+def Convert_Points_to_Lines(POINTS=None, LINES=None, ORDER=None, SEPARATE=None, ELEVATION=None, MEASURE=None, MAXDIST=None, Verbose=2):
     '''
     Convert Points to Line(s)
     ----------
     [shapes_lines.1]\n
-    Converts points to line(s).\n
+    The tool allows one to convert points into lines. Several attributes can be specified to control the construction of the lines:\n
+    (-) an attribute that specifies the order of the points along each line\n
+    (-) an attribute with a line identifier that is used to separate lines\n
+    (-) an attribute with height information that is used as vertex Z value (output shapes layer will be of type XYZ)\n
+    (-) an attribute with measure information that is used as vertex M value (output shapes layer will be of type XYZM)\n
+    If no attributes are specified, a single line is constructed from the points in the saved sequence.\n
     Arguments
     ----------
     - POINTS [`input shapes`] : Points
@@ -73,6 +78,7 @@ def Convert_Points_to_Lines(POINTS=None, LINES=None, ORDER=None, SEPARATE=None,
     - ORDER [`table field`] : Order by...
     - SEPARATE [`table field`] : Separate by...
     - ELEVATION [`table field`] : Elevation
+    - MEASURE [`table field`] : Measure
     - MAXDIST [`floating point number`] : Maximum Distance. Minimum: 0.000000 Default: 0.000000 Maximum distance allowed to connect two consecutive points. Ignored if set to zero (default).
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
@@ -87,16 +93,22 @@ def Convert_Points_to_Lines(POINTS=None, LINES=None, ORDER=None, SEPARATE=None,
         Tool.Set_Option('ORDER', ORDER)
         Tool.Set_Option('SEPARATE', SEPARATE)
         Tool.Set_Option('ELEVATION', ELEVATION)
+        Tool.Set_Option('MEASURE', MEASURE)
         Tool.Set_Option('MAXDIST', MAXDIST)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_lines_1(POINTS=None, LINES=None, ORDER=None, SEPARATE=None, ELEVATION=None, MAXDIST=None, Verbose=2):
+def run_tool_shapes_lines_1(POINTS=None, LINES=None, ORDER=None, SEPARATE=None, ELEVATION=None, MEASURE=None, MAXDIST=None, Verbose=2):
     '''
     Convert Points to Line(s)
     ----------
     [shapes_lines.1]\n
-    Converts points to line(s).\n
+    The tool allows one to convert points into lines. Several attributes can be specified to control the construction of the lines:\n
+    (-) an attribute that specifies the order of the points along each line\n
+    (-) an attribute with a line identifier that is used to separate lines\n
+    (-) an attribute with height information that is used as vertex Z value (output shapes layer will be of type XYZ)\n
+    (-) an attribute with measure information that is used as vertex M value (output shapes layer will be of type XYZM)\n
+    If no attributes are specified, a single line is constructed from the points in the saved sequence.\n
     Arguments
     ----------
     - POINTS [`input shapes`] : Points
@@ -104,6 +116,7 @@ def run_tool_shapes_lines_1(POINTS=None, LINES=None, ORDER=None, SEPARATE=None,
     - ORDER [`table field`] : Order by...
     - SEPARATE [`table field`] : Separate by...
     - ELEVATION [`table field`] : Elevation
+    - MEASURE [`table field`] : Measure
     - MAXDIST [`floating point number`] : Maximum Distance. Minimum: 0.000000 Default: 0.000000 Maximum distance allowed to connect two consecutive points. Ignored if set to zero (default).
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
@@ -118,6 +131,7 @@ def run_tool_shapes_lines_1(POINTS=None, LINES=None, ORDER=None, SEPARATE=None,
         Tool.Set_Option('ORDER', ORDER)
         Tool.Set_Option('SEPARATE', SEPARATE)
         Tool.Set_Option('ELEVATION', ELEVATION)
+        Tool.Set_Option('MEASURE', MEASURE)
         Tool.Set_Option('MAXDIST', MAXDIST)
         return Tool.Execute(Verbose)
     return False
@@ -912,7 +926,7 @@ def run_tool_shapes_lines_14(PARTS=None, LINES=None, EPSILON=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Line_Density(LINES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, POPULATION=None, RADIUS=None, UNIT=None, SHAPE=None, OUTPUT=None, SCALING=None, NO_ZERO=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def Line_Density(LINES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, POPULATION=None, RADIUS=None, UNIT=None, SHAPE=None, OUTPUT=None, SCALING=None, NO_ZERO=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
     '''
     Line Density
     ----------
@@ -938,6 +952,7 @@ def Line_Density(LINES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, POPULAT
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
 
@@ -966,12 +981,13 @@ def Line_Density(LINES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, POPULAT
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_lines_15(LINES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, POPULATION=None, RADIUS=None, UNIT=None, SHAPE=None, OUTPUT=None, SCALING=None, NO_ZERO=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def run_tool_shapes_lines_15(LINES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=None, POPULATION=None, RADIUS=None, UNIT=None, SHAPE=None, OUTPUT=None, SCALING=None, NO_ZERO=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
     '''
     Line Density
     ----------
@@ -997,6 +1013,7 @@ def run_tool_shapes_lines_15(LINES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=N
     - TARGET_USER_YMAX [`floating point number`] : North. Default: 100.000000
     - TARGET_USER_COLS [`integer number`] : Columns. Minimum: 1 Default: 101 Number of cells in East-West direction.
     - TARGET_USER_ROWS [`integer number`] : Rows. Minimum: 1 Default: 101 Number of cells in North-South direction.
+    - TARGET_USER_FLAT [`boolean`] : Rounding. Default: 1 Round bounding coordinates to multiples of cell size. Ignored if cell size has decimal places.
     - TARGET_USER_FITS [`choice`] : Fit. Available Choices: [0] nodes [1] cells Default: 0
     - TARGET_SYSTEM [`grid system`] : Grid System
 
@@ -1025,6 +1042,7 @@ def run_tool_shapes_lines_15(LINES=None, TARGET_TEMPLATE=None, TARGET_OUT_GRID=N
         Tool.Set_Option('TARGET_USER_YMAX', TARGET_USER_YMAX)
         Tool.Set_Option('TARGET_USER_COLS', TARGET_USER_COLS)
         Tool.Set_Option('TARGET_USER_ROWS', TARGET_USER_ROWS)
+        Tool.Set_Option('TARGET_USER_FLAT', TARGET_USER_FLAT)
         Tool.Set_Option('TARGET_USER_FITS', TARGET_USER_FITS)
         Tool.Set_Option('TARGET_SYSTEM', TARGET_SYSTEM)
         return Tool.Execute(Verbose)
