@@ -84,6 +84,12 @@ CQGIS_ToolBox::CQGIS_ToolBox(void)
 		"",
 		"Category|Library"
 	);
+
+	Parameters.Add_Bool(
+		"", "LOAD_ALL" , "Load All Standard Tool Libraries",
+		"",
+		true
+	);
 }
 
 
@@ -94,6 +100,12 @@ CQGIS_ToolBox::CQGIS_ToolBox(void)
 //---------------------------------------------------------
 bool CQGIS_ToolBox::On_Execute(void)
 {
+	if( Parameters("LOAD_ALL")->asBool() )
+	{
+		SG_Get_Tool_Library_Manager().Add_Default_Libraries();
+	}
+
+	//-----------------------------------------------------
 	CSG_String Directory(Parameters("DIRECTORY")->asString());
 
 	if( Parameters("CLEAR")->asBool() )
@@ -230,14 +242,36 @@ bool CQGIS_ToolBox::On_Execute(void)
 		if( Stream.Open(SG_File_Make_Path(Directory, "readme", "txt"), SG_FILE_W, false) )
 		{
 			Stream.Write(
-				"Replace the SAGA binaries in:\n"
-				"> C:\\Program Files\\QGIS X.Y\\apps\\saga\n"
-				"\n"
-				"Replace the tools interface ('description\\' and 'SagaNameDecorator.py' in:\n"
-				"> C:\\Program Files\\QGIS X.Y\\apps\\qgis(-ltr)\\python\\plugins\\processing\\sagaprovider\n"
-				"\n"
-				"Adjust version in file 'SagaAlgorithmProvider.py', e.g.:\n"
-				"> BETA_SUPPORT_VERSION = '9.'\n"
+				"The generated tool interface makes it possible to use this SAGA version in QGIS.\n\n"
+				"SUMMARY:\n"
+				"- install the SAGA binaries to a folder of your choice\n"
+				"- install and configure the \"SAGA Next Gen\" QGIS provider\n"
+				"- update the tool interface of the provider with the generated one\n\n"
+				"STEP BY STEP:\n"
+				"- install or unzip the SAGA binaries to a folder of your choice\n"
+				"- start QGIS\n"
+				"- open the plugins dialog: menu \"Plugins > Manage and Install Plugins...\"\n"
+				"- enable \"Show also Experimental Plugins\" in the settings\n"
+				"- in \"All\", search for \"saga\" and enable the \"Processing SAGA NextGen Provider\" (this installs the provider)\n"
+				"- close the plugins dialog\n"
+				"- open the toolbox dialog: menu \"Processing > Toolbox\"\n"
+				"- open the toolbox's \"Options\" dialog and open \"Providers > SAGANG\"\n"
+				"- set the \"SAGA folder\" to the installation folder of the SAGA binaries\n"
+				"- check the \"Enable SAGA Import/Export optimizations\" option\n"
+				"- close the options dialog, now the \"SAGA Next Gen\" provider shows up in the toolbox dialog\n"
+				"- close QGIS\n"
+				"- update the SAGA interface description of the provider:\n"
+				"- the plugin installation folder is\n"
+				"  for MS Windows\n"
+				"    C:\\Users\\my_username\\AppData\\Roaming\\QGIS\\QGIS3\\profiles\\default\\python\\plugins\\processing_saga_nextgen\n"
+				"  for Unix-likes\n"
+				"    ~/.local/share/QGIS/QGIS3/profiles/default/python/plugins/processing_saga_nextgen\n"
+				"- replace the \"description\" folder with the generated one\n"
+				"- replace the \"SagaNameDecorator.py\" file in the \"processing\" subfolder\n"
+				"- edit the file \"processing/provider.py\" and set the\n"
+				"  REQUIRED_VERSION = 'x.x.' to the version of your SAGA binaries, e.g.\n"
+				"  REQUIRED_VERSION = '9.2.'\n"
+				"- start QGIS and enjoy SAGA\n"
 			);
 		}
 	}
@@ -538,6 +572,7 @@ bool CQGIS_ToolBox::Get_Parameter(CSG_Parameter *pParameter, CSG_String &Paramet
 		if( pParameter->asValue()->has_Maximum() ) { PARAMETER_FLT(pParameter->asValue()->Get_Maximum()); } else { PARAMETER_STR("None"); }
 		break;
 
+	case PARAMETER_TYPE_Data_Type      :
 	case PARAMETER_TYPE_Choice         :
 		PARAMETER_SET("Enum");
 		PARAMETER_STR(Get_Choices(pParameter->asChoice()));
